@@ -48,10 +48,12 @@ my $bogus_smtp = 'mail.mail.com';
 my %tool_constants = (
     'eumm'  => {
         module  => 'ExtUtils::MakeMaker',
+        have    => eval "require ExtUtils::MakeMaker" || 0,
         PL      => 'Makefile.PL',
     },
     'mb'    => {
         module  => 'Module::Build',
+        have    => eval "require Module::Build" || 0,
         PL      => 'Build.PL'
     },
 );
@@ -97,7 +99,7 @@ sub test_fake_config {
 # Test grade_PL
 #--------------------------------------------------------------------------#
 
-sub test_grade_PL_iter_plan() { 6 }
+sub test_grade_PL_iter_plan() { 5 }
 sub test_grade_PL_plan() { test_grade_PL_iter_plan() * 2 } 
 sub test_grade_PL {
     my ($case, $dist) = @_;
@@ -107,13 +109,14 @@ sub test_grade_PL {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($tool_mod,$tool_PL) = @{$tool_constants{$tool}}{qw/module PL/};
-            my $tool_cmd = $tool eq 'eumm'  ? "$perl Makefile.PL" 
-                                            : "$perl Build.PL";
+            my ($have_tool,$tool_mod,$tool_PL) = 
+                @{$tool_constants{$tool}}{qw/have module PL/};
+            my $tool_label = $tool eq 'eumm'  ? "Makefile.PL" 
+                                            : "Build.PL";
+            my $tool_cmd = "$perl $tool_label"; 
 
-            eval "require $tool_mod";
-            skip "$tool_mod not installed", test_grade_PL_iter_plan()
-                if $@;
+            skip "$tool_mod not installed or working", test_grade_PL_iter_plan()
+                if ! $have_tool;
             
             my $tempd = _ok_clone_dist_dir( $case->{name} );
             
@@ -148,35 +151,58 @@ sub test_grade_PL {
             );
             
             my $case_grade = $case->{"$tool\_grade"};
-
-            # correct grade identified?
             my $is_grade_correct;
-            like( $stdout, "/^CPAN::Reporter: \Q$tool_PL\E result is '$case_grade'/ms",
-                "$case->{name}: $tool_PL grade identified as '$case_grade'"
-            ) and $is_grade_correct++;
-            my $case_msg = $case->{"$tool\_msg"};
-            like( $stdout, "/\Q$case_msg\E/",
-                "$case->{name}: $tool_PL grade explanation correct"
-            );
 
-            # expectations differ by grade
-            if ( $case_grade =~ m{fail|unknown|na} ) {
-                # report should have been sent
-                like( $stdout, "/Preparing a CPAN Testers report for \Q$short_name\E/",
-                    "$case->{name}: report notification correct"
+            # Grade evaluation with special case if discarding
+            my ($found_grade_result, $found_msg) = 
+                ( $stdout =~ /^CPAN::Reporter: ([^,]+), ([^\n]+)/ms );
+            if ( $case_grade eq 'discard' ) {
+                is ($found_grade_result, "test results were not valid",
+                    "$case->{name}: '$tool_label' prerequisites not satisifed"
                 );
-                ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
-                    "$case->{name}: report was mock sent"
+                    
+                like( $stdout, 
+                    "/Test report will not be sent/",
+                    "$case->{name}: discard message correct"
+                ) and $is_grade_correct++;
+
+                ok( ! defined $t::Helper::sent_report,
+                    "$case->{name}: test results discarded"
                 );
             }
-            else { # pass
-                # report shouldn't have been sent
-                ok( ! defined $t::Helper::sent_report ,
-                    "$case->{name}: no $tool_PL report was sent"
-                );
-                pass("$case->{name}: (advancing test count)");
+            else {
+                my ($found_grade) = ( $found_grade_result =~ /$tool_label result is '([^']+)'/ );
+                is( $found_grade, $case_grade, 
+                    "$case->{name}: '$tool_label' grade reported as '$case_grade'"
+                ) or _diag_output( $stdout, $stderr );
+                
+                my $ctr_regex = "/preparing a CPAN Testers report for \Q$short_name\E/";
+                
+                if ( $case_grade eq 'pass' ) {
+                    unlike( $stdout, $ctr_regex ,
+                        "$case->{name}: report notification correct"
+                    ) and $is_grade_correct++;
+                    ok( ! defined $t::Helper::sent_report,
+                        "$case->{name}: results not sent"
+                    );
+                }
+                else {
+                    like( $stdout, $ctr_regex ,
+                        "$case->{name}: report notification correct"
+                    ) and $is_grade_correct++;
+                    if ( -r $config_file ) {
+                        ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
+                            "$case->{name}: report was mock sent"
+                        );
+                    }
+                    else {
+                        ok( ! defined $t::Helper::sent_report,
+                            "$case->{name}: results not sent"
+                        );
+                    }
+                }
             }
-            
+
             _diag_output( $stdout, $stderr ) 
                 unless ( $is_rc_correct && $is_grade_correct );
         } # SKIP
@@ -187,7 +213,7 @@ sub test_grade_PL {
 # Test grade_make
 #--------------------------------------------------------------------------#
 
-sub test_grade_make_iter_plan() { 7 }
+sub test_grade_make_iter_plan() { 6 }
 sub test_grade_make_plan() { test_grade_make_iter_plan() * 2 } 
 sub test_grade_make {
     my ($case, $dist) = @_;
@@ -197,13 +223,13 @@ sub test_grade_make {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($tool_mod,$tool_PL) = @{$tool_constants{$tool}}{qw/module PL/};
+            my ($have_tool,$tool_mod,$tool_PL) = 
+                @{$tool_constants{$tool}}{qw/have module PL/};
             my $tool_cmd = $tool eq 'eumm' ? $Config{make} : "$perl Build";
             my $tool_label = $tool eq 'eumm' ? $Config{make} : "Build";
 
-            eval "require $tool_mod";
-            skip "$tool_mod not installed", test_grade_make_iter_plan()
-                if $@;
+            skip "$tool_mod not installed or working", test_grade_make_iter_plan()
+                if ! $have_tool;
             
             # Set up temporary directory for the case
             my $tempd = _ok_clone_dist_dir( $case->{name} );
@@ -248,33 +274,56 @@ sub test_grade_make {
             );
 
             my $case_grade = $case->{"$tool\_grade"};
-
-            # correct grade identified?
             my $is_grade_correct;
-            like( $stdout, "/^CPAN::Reporter: \Q$tool_label\E result is '$case_grade'/ms",
-                "$case->{name}: $tool_label grade identified as '$case_grade'"
-            ) and $is_grade_correct++;
-            my $case_msg = $case->{"$tool\_msg"};
-            like( $stdout, "/\Q$case_msg\E/",
-                "$case->{name}: $tool_label grade explanation correct"
-            );
 
-            # expectations are different by grade
-            if ( $case_grade =~ m{fail|unknown|na} ) {
-                # report should have been sent
-                like( $stdout, "/Preparing a CPAN Testers report for \Q$short_name\E/",
-                    "$case->{name}: report notification correct"
+            # Grade evaluation with special case if discarding
+            my ($found_grade_result, $found_msg) = 
+                ( $stdout =~ /^CPAN::Reporter: ([^,]+), ([^\n]+)/ms );
+            if ( $case_grade eq 'discard' ) {
+                is ($found_grade_result, "test results were not valid",
+                    "$case->{name}: '$tool_label' prerequisites not satisifed"
                 );
-                ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
-                    "$case->{name}: report was mock sent"
+                    
+                like( $stdout, 
+                    "/Test report will not be sent/",
+                    "$case->{name}: discard message correct"
+                ) and $is_grade_correct++;
+
+                ok( ! defined $t::Helper::sent_report,
+                    "$case->{name}: test results discarded"
                 );
             }
-            else { # pass
-                # report shouldn't have been sent
-                ok( ! defined $t::Helper::sent_report ,
-                    "$case->{name}: no $tool_label report was sent"
-                );
-                pass("$case->{name}: (advancing test count)");
+            else {
+                my ($found_grade) = ( $found_grade_result =~ /$tool_label result is '([^']+)'/ );
+                is( $found_grade, $case_grade, 
+                    "$case->{name}: '$tool_label' grade reported as '$case_grade'"
+                ) or _diag_output( $stdout, $stderr );
+                
+                my $ctr_regex = "/preparing a CPAN Testers report for \Q$short_name\E/";
+                
+                if ( $case_grade eq 'pass' ) {
+                    unlike( $stdout, $ctr_regex ,
+                        "$case->{name}: report notification correct"
+                    ) and $is_grade_correct++;
+                    ok( ! defined $t::Helper::sent_report,
+                        "$case->{name}: results not sent"
+                    );
+                }
+                else {
+                    like( $stdout, $ctr_regex ,
+                        "$case->{name}: report notification correct"
+                    ) and $is_grade_correct++;
+                    if ( -r $config_file ) {
+                        ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
+                            "$case->{name}: report was mock sent"
+                        );
+                    }
+                    else {
+                        ok( ! defined $t::Helper::sent_report,
+                            "$case->{name}: results not sent"
+                        );
+                    }
+                }
             }
 
             _diag_output( $stdout, $stderr )
@@ -298,15 +347,15 @@ sub test_grade_test {
 
     for my $tool ( qw/eumm mb/ ) {
         SKIP: {
-            my ($tool_mod,$tool_PL) = @{$tool_constants{$tool}}{qw/module PL/};
+            my ($have_tool,$tool_mod,$tool_PL) = 
+                @{$tool_constants{$tool}}{qw/have module PL/};
             my $tool_cmd = $tool eq 'eumm'  ?  "$make test"
                                             :  "$perl Build test" ;
             my $tool_label = $tool eq 'eumm'?  "make test"
                                             :  "perl Build test" ;
 
-            eval "require $tool_mod";
-            skip "$tool_mod not installed", test_grade_test_iter_plan()
-                if $@;
+            skip "$tool_mod not installed or working", test_grade_test_iter_plan()
+                if ! $have_tool; 
 
             my $tempd = _ok_clone_dist_dir( $case->{name} );
                 
@@ -348,12 +397,12 @@ sub test_grade_test {
             my ($found_grade_result, $found_msg) = 
                 ( $stdout =~ /^CPAN::Reporter: ([^,]+), ([^\n]+)/ms );
             if ( $case->{"$tool\_grade"} eq 'discard' ) {
-                is ($found_grade_result, "Test results were not valid",
+                is ($found_grade_result, "test results were not valid",
                     "$case->{name}: '$tool_label' prerequisites not satisifed"
                 );
                     
                 like( $stdout, 
-                    "/Test results for \Q$short_name\E will be discarded/",
+                    "/Test report will not be sent/",
                     "$case->{name}: discard message correct"
                 );
 
@@ -368,7 +417,7 @@ sub test_grade_test {
                     "$case->{name}: '$tool_label' grade reported as '$case_grade'"
                 ) or _diag_output( $stdout, $stderr );
                 
-                like( $stdout, "/Preparing a CPAN Testers report for \Q$short_name\E/",
+                like( $stdout, "/preparing a CPAN Testers report for \Q$short_name\E/",
                     "$case->{name}: report notification correct"
                 );
 
@@ -385,7 +434,8 @@ sub test_grade_test {
             }
             
             # Grade explanation message
-            is( $found_msg, $case->{"$tool\_msg"} . ".",
+            is( $found_msg, 
+                $case->{"$tool\_msg"} ? $case->{"$tool\_msg"} . q{.} : q{},
                 "$case->{name}: '$tool_label' grade explanation correct"
             );
 
@@ -406,8 +456,10 @@ HERE
     'fail' => <<'HERE',
 Thank you for uploading your work to CPAN.  However, it appears that
 there were some problems with your distribution.  If these results are 
-not what you expect, please consult "Notes for CPAN Authors" on 
-the CPAN Testers Wiki: http://cpantest.grango.org
+not what you expect or if you would like to learn how to avoid FAIL 
+reports for missing dependencies, unsupported operating systems, etc.,
+please consult "Notes for CPAN Authors" on the CPAN Testers Wiki: 
+http://cpantest.grango.org
 HERE
 
     'unknown' => << 'HERE',
@@ -544,7 +596,7 @@ sub test_report {
         "$label cc list correct"
     );
 
-    return;
+    return ($stdout, $stderr, $err, $test_output);
 };
 
 #--------------------------------------------------------------------------#
@@ -576,7 +628,7 @@ sub test_dispatch {
         ok( defined $t::Helper::sent_report && length $t::Helper::sent_report,
             "report was sent for $case->{label}"
         );
-        like( $stdout, "/Sending test report with/",
+        like( $stdout, "/sending test report with/",
             "saw report sent message for $case->{label}"
         );
     }
